[LON-CAPA-cvs] cvs: loncom /homework chemresponse.pm /interface loncommon.pm londropadd.pm lonhelper.pm lonhtmlcommon.pm lonnavmaps.pm lonpreferences.pm lonsearchcat.pm /interface/statistics lonstudentassessment.pm /xml lonplot.pm

www lon-capa-cvs@mail.lon-capa.org
Mon, 08 Mar 2004 17:31:38 -0000


This is a MIME encoded message

--www1078767098
Content-Type: text/plain

www		Mon Mar  8 12:31:38 2004 EDT

  Modified files:              
    /loncom/homework	chemresponse.pm 
    /loncom/interface	loncommon.pm londropadd.pm lonhelper.pm 
                     	lonhtmlcommon.pm lonnavmaps.pm lonpreferences.pm 
                     	lonsearchcat.pm 
    /loncom/interface/statistics	lonstudentassessment.pm 
    /loncom/xml	lonplot.pm 
  Log:
  Typos: "separate"
  
  
--www1078767098
Content-Type: text/plain
Content-Disposition: attachment; filename="www-20040308123138.txt"

Index: loncom/homework/chemresponse.pm
diff -u loncom/homework/chemresponse.pm:1.29 loncom/homework/chemresponse.pm:1.30
--- loncom/homework/chemresponse.pm:1.29	Fri Feb 13 10:12:57 2004
+++ loncom/homework/chemresponse.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.29 2004/02/13 15:12:57 www Exp $
+# $Id: chemresponse.pm,v 1.30 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -35,7 +35,7 @@
     &Apache::lonxml::register('Apache::chemresponse',('organicresponse','organicstructure','reactionresponse'));
 }
 
-sub seperate_jme_window {
+sub separate_jme_window {
     my ($smile_input,$jme_input,$molecule,$options)=@_;
     my $smilesection;
     if (defined($smile_input)) {
@@ -117,7 +117,7 @@
 	}
 	my $options=&Apache::lonxml::get_param('options',$parstack,
 					       $safeeval);
-	$result=&seperate_jme_window("HWVAL_$id","MOLECULE_$id",$molecule,$options);
+	$result=&separate_jme_window("HWVAL_$id","MOLECULE_$id",$molecule,$options);
 	$result.= '<input type="hidden" name="MOLECULE_'.$id.'" value="" />';
     } elsif ($target eq 'edit') {
 	$result .=&Apache::edit::tag_start($target,$token);
@@ -129,7 +129,7 @@
 				    $token,40);
 	my $molecule=&Apache::lonxml::get_param('molecule',$parstack,
 						$safeeval);
-	$result .=&seperate_jme_window(undef,
+	$result .=&separate_jme_window(undef,
 		      &Apache::edit::html_element_name('molecule'),
 		      $molecule,$options);
 	$result .='</nobr><br /><nobr>';
@@ -138,7 +138,7 @@
 	$result .=&Apache::edit::hidden_arg('jmeanswer',$token);
 	my $jmeanswer=&Apache::lonxml::get_param('jmeanswer',$parstack,
 						 $safeeval);
-	$result .=&seperate_jme_window(
+	$result .=&separate_jme_window(
                       &Apache::edit::html_element_name('answer'),
                       &Apache::edit::html_element_name('jmeanswer'),
 		      $jmeanswer,$options);
@@ -248,7 +248,7 @@
 	    $options.= ',multipart,number';
 	}
 						   
-	$result .=&seperate_jme_window(undef,
+	$result .=&separate_jme_window(undef,
 				 &Apache::edit::html_element_name('molecule'),
 				       $molecule,$options);
 	$result.="</nobr><br />";
Index: loncom/interface/loncommon.pm
diff -u loncom/interface/loncommon.pm:1.184 loncom/interface/loncommon.pm:1.185
--- loncom/interface/loncommon.pm:1.184	Mon Feb 23 16:10:06 2004
+++ loncom/interface/loncommon.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common routines
 #
-# $Id: loncommon.pm,v 1.184 2004/02/23 21:10:06 albertel Exp $
+# $Id: loncommon.pm,v 1.185 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -220,10 +220,10 @@
 the element that the results of the browsing selection are to be placed in. 
 
 Specifying 'only' will restrict the browser to displaying only files
-with the given extension.  Can be a comma seperated list.
+with the given extension.  Can be a comma separated list.
 
 Specifying 'omit' will restrict the browser to NOT displaying files
-with the given extension.  Can be a comma seperated list.
+with the given extension.  Can be a comma separated list.
 
 =item * opensearcher(formname, elementname) [javascript]
 
@@ -716,7 +716,7 @@
 
 =item * csv_translate($text) 
 
-Translate $text to allow it to be output as a 'comma seperated values' 
+Translate $text to allow it to be output as a 'comma separated values' 
 format.
 
 =cut
@@ -3198,7 +3198,7 @@
 =item $Xlabels: Array ref containing the labels to be used for the X-axis.
 
 =item $Ydata: Array ref containing Array refs.  
-Each of the contained arrays will be plotted as a seperate curve.
+Each of the contained arrays will be plotted as a separate curve.
 
 =item %Values: hash indicating or overriding any default values which are 
 passed to graph.png.  
Index: loncom/interface/londropadd.pm
diff -u loncom/interface/londropadd.pm:1.106 loncom/interface/londropadd.pm:1.107
--- loncom/interface/londropadd.pm:1.106	Mon Mar  1 11:34:54 2004
+++ loncom/interface/londropadd.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to drop and add students in courses 
 #
-# $Id: londropadd.pm,v 1.106 2004/03/01 16:34:54 matthew Exp $
+# $Id: londropadd.pm,v 1.107 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -699,7 +699,7 @@
     $ENV{'form.csec'}=~s/\W//g;
     #
     # We do the dates first because the action of making them the defaul
-    # in the course is entirely seperate from the action of enrolling the
+    # in the course is entirely separate from the action of enrolling the
     # student.  Also, a failure in setting the dates as default is not fatal
     # to the process of enrolling / modifying a student.
     my ($startdate,$enddate) = &get_dates_from_form();
Index: loncom/interface/lonhelper.pm
diff -u loncom/interface/lonhelper.pm:1.64 loncom/interface/lonhelper.pm:1.65
--- loncom/interface/lonhelper.pm:1.64	Fri Feb 27 14:51:46 2004
+++ loncom/interface/lonhelper.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # .helper XML handler to implement the LON-CAPA helper
 #
-# $Id: lonhelper.pm,v 1.64 2004/02/27 19:51:46 albertel Exp $
+# $Id: lonhelper.pm,v 1.65 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -230,7 +230,7 @@
 # In the debugger, this means that breakpoints are ignored until you step into
 # a function and get out of what must be a "faked up scope" in the Apache->
 # mod_perl connection. In this code, it was manifesting itself in the existence
-# of two seperate file-scoped $helper variables, one set to the value of the
+# of two separate file-scoped $helper variables, one set to the value of the
 # helper in the helper constructor, and one referenced by the handler on the
 # "$helper->process()" line. Using the debugger, one could actually
 # see the two different $helper variables, as hashes at completely
Index: loncom/interface/lonhtmlcommon.pm
diff -u loncom/interface/lonhtmlcommon.pm:1.59 loncom/interface/lonhtmlcommon.pm:1.60
--- loncom/interface/lonhtmlcommon.pm:1.59	Wed Mar  3 17:55:35 2004
+++ loncom/interface/lonhtmlcommon.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.59 2004/03/03 22:55:35 matthew Exp $
+# $Id: lonhtmlcommon.pm,v 1.60 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -928,7 +928,7 @@
         # Make the faq and bug data cascade
         my $faq = '';
         my $bug = '';
-        # The last breadcrumb does not have a link, so handle it seperately.
+        # The last breadcrumb does not have a link, so handle it separately.
         my $last = pop(@Crumbs);
         #
         # The first one should be the course, I guess.
Index: loncom/interface/lonnavmaps.pm
diff -u loncom/interface/lonnavmaps.pm:1.250 loncom/interface/lonnavmaps.pm:1.251
--- loncom/interface/lonnavmaps.pm:1.250	Fri Mar  5 16:51:50 2004
+++ loncom/interface/lonnavmaps.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Navigate Maps Handler
 #
-# $Id: lonnavmaps.pm,v 1.250 2004/03/05 21:51:50 albertel Exp $
+# $Id: lonnavmaps.pm,v 1.251 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -314,9 +314,9 @@
     return $res->src();
 }
 
-# Convenience function: This seperates the logic of how to create
+# Convenience function: This separates the logic of how to create
 # the problem text strings ("Due: DATE", "Open: DATE", "Not yet assigned",
-# etc.) into a seperate function. It takes a resource object as the
+# etc.) into a separate function. It takes a resource object as the
 # first parameter, and the part number of the resource as the second.
 # It's basically a big switch statement on the status of the resource.
 
@@ -2742,7 +2742,7 @@
 #  useful for pre-processing of some kind, and is in fact used by the main
 #  iterator that way, but that's about it.
 # One could imagine merging this into the init routine of the main iterator,
-#  but this might as well be left seperate, since it is possible some other
+#  but this might as well be left separate, since it is possible some other
 #  use might be found for it. - Jeremy
 
 # Unlike the main iterator, this DOES return all resources, even blank ones.
@@ -3850,7 +3850,7 @@
 
     my $status = $self->queryRestoreHash('solved', shift);
 
-    # Left as seperate if statements in case we ever do more with this
+    # Left as separate if statements in case we ever do more with this
     if ($status eq 'correct_by_student') {return $self->CORRECT;}
     if ($status eq 'correct_by_override') {return $self->CORRECT_BY_OVERRIDE; }
     if ($status eq 'incorrect_attempted') {return $self->INCORRECT; }
Index: loncom/interface/lonpreferences.pm
diff -u loncom/interface/lonpreferences.pm:1.35 loncom/interface/lonpreferences.pm:1.36
--- loncom/interface/lonpreferences.pm:1.35	Fri Feb 20 20:31:04 2004
+++ loncom/interface/lonpreferences.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Preferences
 #
-# $Id: lonpreferences.pm,v 1.35 2004/02/21 01:31:04 matthew Exp $
+# $Id: lonpreferences.pm,v 1.36 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -63,7 +63,7 @@
 ##################################################
 sub des_keys {
     # Make a new key for DES encryption.
-    # Each key has two parts which are returned seperately.
+    # Each key has two parts which are returned separately.
     # Please note:  Each key must be passed through the &hex function
     # before it is output to the web browser.  The hex versions cannot
     # be used to decrypt.
@@ -503,7 +503,7 @@
 $errormessage
 
 <p>
-<!-- We seperate the forms into 'server' and 'client' in order to
+<!-- We separate the forms into 'server' and 'client' in order to
      ensure that unencrypted passwords will not be sent out by a
      crappy browser -->
 
Index: loncom/interface/lonsearchcat.pm
diff -u loncom/interface/lonsearchcat.pm:1.204 loncom/interface/lonsearchcat.pm:1.205
--- loncom/interface/lonsearchcat.pm:1.204	Wed Mar  3 12:25:23 2004
+++ loncom/interface/lonsearchcat.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Search Catalog
 #
-# $Id: lonsearchcat.pm,v 1.204 2004/03/03 17:25:23 matthew Exp $
+# $Id: lonsearchcat.pm,v 1.205 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -48,7 +48,7 @@
 lonsearchcat presents the user with an interface to search the LON-CAPA
 digital library.  lonsearchcat also initiates the execution of a search
 by sending the search parameters to LON-CAPA servers.  The progress of 
-search (on a server basis) is displayed to the user in a seperate window.
+search (on a server basis) is displayed to the user in a separate window.
 
 =head1 Internals
 
@@ -882,7 +882,7 @@
 
 Store variables away to the %persistent_db.
 Values will be escaped.  Values that are array pointers will have their
-elements escaped and concatenated in a comma seperated string.  
+elements escaped and concatenated in a comma separated string.  
 
 =cut
 
@@ -914,7 +914,7 @@
 
 Store most form variables away to the %persistent_db.
 Values will be escaped.  Values that are array pointers will have their
-elements escaped and concatenated in a comma seperated string.  
+elements escaped and concatenated in a comma separated string.  
 
 =cut
 
Index: loncom/interface/statistics/lonstudentassessment.pm
diff -u loncom/interface/statistics/lonstudentassessment.pm:1.95 loncom/interface/statistics/lonstudentassessment.pm:1.96
--- loncom/interface/statistics/lonstudentassessment.pm:1.95	Mon Mar  1 11:39:19 2004
+++ loncom/interface/statistics/lonstudentassessment.pm	Mon Mar  8 12:31:37 2004
@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentassessment.pm,v 1.95 2004/03/01 16:39:19 matthew Exp $
+# $Id: lonstudentassessment.pm,v 1.96 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -402,7 +402,7 @@
    },
      { name  => 'CSV',
        value => 'csv',
-       description => 'Output a comma seperated values file suitable for '.
+       description => 'Output a comma separated values file suitable for '.
            'import into a spreadsheet program.  Using this method as opposed '.
            'to Excel output allows you to organize your data before importing'.
            ' it into a spreadsheet program.',
Index: loncom/xml/lonplot.pm
diff -u loncom/xml/lonplot.pm:1.94 loncom/xml/lonplot.pm:1.95
--- loncom/xml/lonplot.pm:1.94	Wed Jan  7 13:16:02 2004
+++ loncom/xml/lonplot.pm	Mon Mar  8 12:31:37 2004
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.94 2004/01/07 18:16:02 matthew Exp $
+# $Id: lonplot.pm,v 1.95 2004/03/08 17:31:37 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -401,7 +401,7 @@
 in the order gnuplot expects the data.
 </p><p>
 Specifying the data should usually be done with a perl variable or array, 
-such as \@Xdata and \@Ydata.  You may also specify numerical data seperated 
+such as \@Xdata and \@Ydata.  You may also specify numerical data separated 
 by commas.  Again, the order of the <b>data</b> tags is important.  The
 first tag will be the X data and the second will be the Y data.
 </p>
@@ -512,7 +512,7 @@
     my $randnumber;
     # need to call rand everytime start_script would evaluate, as the
     # safe space rand number generator and the global rand generator 
-    # are not seperate
+    # are not separate
     if ($target eq 'web' || $target eq 'tex' || $target eq 'grade' ||
 	$target eq 'answer') {
       $randnumber=int(rand(1000));
@@ -887,7 +887,7 @@
 	my @data;
 	if ($datatext =~ /,/) { # comma deliminated
 	    @data = split /,/,$datatext;
-	} else { # Assume it's space seperated.
+	} else { # Assume it's space separated.
 	    @data = split / /,$datatext;
 	}
 	for (my $i=0;$i<=$#data;$i++) {

--www1078767098--